==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/other_game_porker.php <==
<?php
//==============================================================
// Program Name		: ݡ
// File Name		: other_game_porker.php
//--------------------------------------------------------------
// Date             : 2000/08/25
// Author           : M Iura
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");


define("NEXT_PG_NAME", "other_game_porker_play.php");	// ץ̾
define("TABLE_WIDTH", 600);								// ơ֥
define("SPACE_IMG", $JJ_IMG_ROOT . "spacer.gif");		// 򥤥᡼


//==============================================================
// Function Name    : Print_Syoki
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Print_syoki()
{
	global $CHG;

	print("ϥԥ塼Ǥ<BR><BR>\n");
	print("ޤǽ ɤθ򴹲 ꤷƤ<BR><BR>\n");

	print("<form action=\"" . NEXT_PG_NAME . "\" method=\"post\">\n");
	print("򴹲<SELECT NAME=\"CHG\">\n");
	print("  <OPTION VALUE=\"2\">\n");
	print("  <OPTION VALUE=\"3\">\n");
	print("  <OPTION VALUE=\"4\">\n");
	print("  <OPTION VALUE=\"5\">\n");
	print("  <OPTION VALUE=\"6\">\n");
	print("</SELECT><BR>\n");
	print("<input type=\"hidden\" name=\"point\" 	value=5	>\n");
	print("<input type=\"submit\" value=\"೫ϡ\"></TD>\n");
	print("</form>\n");
}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

include("common_printheader.inc");

printf("<table border=\"0\" width=\"%d\" cellpadding=\"5\" cellspacing=\"0\">\n", TABLE_WIDTH);

print("<tr bgcolor=\"#cccccc\">\n");
print("<td align=\"center\" class=\"color00\" width=\"50%\"><b>ݡ</b></td>\n");
print("<td width=\"50%\">&nbsp;</td>\n");
print("</tr>\n");

print("<tr class=\"color00\">\n");
printf("<td colspan=\"2\"><img src=\"%s\"></td>\n", SPACE_IMG);
print("</tr>\n");

print("<tr><td colspan=\"2\" bgcolor=\"white\" align=\"center\">\n");
print_Syoki();
print("</td></tr>\n");

print("</table>\n");

include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/other_game_porker.php <==
<?php
//==============================================================
// Program Name		: ݡ
// File Name		: other_game_porker.php
//--------------------------------------------------------------
// Date             : 2000/08/25
// Author           : M Iura
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");


define("NEXT_PG_NAME", "other_game_porker_play.php");	// ץ̾
define("TABLE_WIDTH", 600);								// ơ֥
define("SPACE_IMG", $JJ_IMG_ROOT . "spacer.gif");		// 򥤥᡼


//==============================================================
// Function Name    : Print_Syoki
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Print_syoki()
{
	global $CHG;

	print("ϥԥ塼Ǥ<BR><BR>\n");
	print("ޤǽ ɤθ򴹲 ꤷƤ<BR><BR>\n");

	print("<form action=\"" . NEXT_PG_NAME . "\" method=\"post\">\n");
	print("򴹲<SELECT NAME=\"CHG\">\n");
	print("  <OPTION VALUE=\"2\">\n");
	print("  <OPTION VALUE=\"3\">\n");
	print("  <OPTION VALUE=\"4\">\n");
	print("  <OPTION VALUE=\"5\">\n");
	print("  <OPTION VALUE=\"6\">\n");
	print("</SELECT><BR>\n");
	print("<input type=\"hidden\" name=\"point\" 	value=5	>\n");
	print("<input type=\"submit\" value=\"೫ϡ\"></TD>\n");
	print("</form>\n");
}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

include("common_printheader.inc");

printf("<table border=\"0\" width=\"%d\" cellpadding=\"5\" cellspacing=\"0\">\n", TABLE_WIDTH);

print("<tr bgcolor=\"#cccccc\">\n");
print("<td align=\"center\" class=\"color00\" width=\"50%\"><b>ݡ</b></td>\n");
print("<td width=\"50%\">&nbsp;</td>\n");
print("</tr>\n");

print("<tr class=\"color00\">\n");
printf("<td colspan=\"2\"><img src=\"%s\"></td>\n", SPACE_IMG);
print("</tr>\n");

print("<tr><td colspan=\"2\" bgcolor=\"white\" align=\"center\">\n");
print_Syoki();
print("</td></tr>\n");

print("</table>\n");

include("common_printfooter.inc");

?>
